sequencetools.partition_sequence_once_by_weights_exactly_without_overhang
=========================================================================

.. autofunction:: abjad.tools.sequencetools.partition_sequence_once_by_weights_exactly_without_overhang
